@@ -1,4 +1,4 @@
-$comment '#define M_NO_MEM "segment nant"'
+$literal '#define M_NO_MEM "segment nant"'
 
 $header "static char *short_right_name[]"
 M_2_NO_RIGHT		"--"
